# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/certificatemanager/v1/certificate_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.certificatemanager.v1 import certificate_pb2 as yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/certificatemanager/v1/certificate_service.proto',
  package='yandex.cloud.certificatemanager.v1',
  syntax='proto3',
  serialized_options=b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<yandex/cloud/certificatemanager/v1/certificate_service.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x34yandex/cloud/certificatemanager/v1/certificate.proto\x1a yandex/cloud/access/access.proto\"\x80\x01\n\x15GetCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateView\"\xbb\x01\n\x17ListCertificatesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x41\n\x04view\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateView\"z\n\x18ListCertificatesResponse\x12\x45\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32/.yandex.cloud.certificatemanager.v1.Certificate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x13ListVersionsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x14ListVersionsResponse\x12=\n\x08versions\x18\x01 \x03(\x0b\x32+.yandex.cloud.certificatemanager.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc2\x03\n\x18\x43reateCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x99\x01\n\x06labels\x18\x04 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12 \n\x0b\x63\x65rtificate\x18\x05 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x06 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12%\n\x0bprivate_key\x18\x07 \x01(\tB\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08\x31-524288\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19\x43reateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xf4\x03\n\x18UpdateCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x99\x01\n\x06labels\x18\x05 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12 \n\x0b\x63\x65rtificate\x18\x06 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x07 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12!\n\x0bprivate_key\x18\x08 \x01(\tB\x0c\x8a\xc8\x31\x08<=524288\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19UpdateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"@\n\x18\x44\x65leteCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x19\x44\x65leteCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xbf\x03\n\x1cRequestNewCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x9d\x01\n\x06labels\x18\x04 \x03(\x0b\x32L.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x0f\n\x07\x64omains\x18\x05 \x03(\t\x12I\n\x0e\x63hallenge_type\x18\x06 \x01(\x0e\x32\x31.yandex.cloud.certificatemanager.v1.ChallengeType\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x1dRequestNewCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x86\x01\n ListCertificateOperationsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListCertificateOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*&\n\x0f\x43\x65rtificateView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\xca\x12\n\x12\x43\x65rtificateService\x12\xb0\x01\n\x03Get\x12\x39.yandex.cloud.certificatemanager.v1.GetCertificateRequest\x1a/.yandex.cloud.certificatemanager.v1.Certificate\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/certificate-manager/v1/certificates/{certificate_id}\x12\xaf\x01\n\x04List\x12;.yandex.cloud.certificatemanager.v1.ListCertificatesRequest\x1a<.yandex.cloud.certificatemanager.v1.ListCertificatesResponse\",\x82\xd3\xe4\x93\x02&\x12$/certificate-manager/v1/certificates\x12\xc9\x01\n\x0cListVersions\x12\x37.yandex.cloud.certificatemanager.v1.ListVersionsRequest\x1a\x38.yandex.cloud.certificatemanager.v1.ListVersionsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/certificate-manager/v1/certificates/{certificate_id}/versions\x12\xc6\x01\n\x06\x43reate\x12<.yandex.cloud.certificatemanager.v1.CreateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02)\"$/certificate-manager/v1/certificates:\x01*\xb2\xd2*(\n\x19\x43reateCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xd7\x01\n\x06Update\x12<.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"l\x82\xd3\xe4\x93\x02:25/certificate-manager/v1/certificates/{certificate_id}:\x01*\xb2\xd2*(\n\x19UpdateCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xd4\x01\n\x06\x44\x65lete\x12<.yandex.cloud.certificatemanager.v1.DeleteCertificateRequest\x1a!.yandex.cloud.operation.Operation\"i\x82\xd3\xe4\x93\x02\x37*5/certificate-manager/v1/certificates/{certificate_id}\xb2\xd2*(\n\x19\x44\x65leteCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xdd\x01\n\nRequestNew\x12@.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest\x1a!.yandex.cloud.operation.Operation\"j\x82\xd3\xe4\x93\x02\x34\"//certificate-manager/v1/certificates/requestNew:\x01*\xb2\xd2*,\n\x1dRequestNewCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xe7\x01\n\x0eListOperations\x12\x44.yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest\x1a\x45.yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/certificate-manager/v1/certificates/{certificate_id}/operations\x12\xc4\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"M\x82\xd3\xe4\x93\x02G\x12\x45/certificate-manager/v1/certificates/{resource_id}:listAccessBindings\x12\xf4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\x82\xd3\xe4\x93\x02I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\x80\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\x82\xd3\xe4\x93\x02L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyB\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,])

_CERTIFICATEVIEW = _descriptor.EnumDescriptor(
  name='CertificateView',
  full_name='yandex.cloud.certificatemanager.v1.CertificateView',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2979,
  serialized_end=3017,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEVIEW)

CertificateView = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATEVIEW)
BASIC = 0
FULL = 1



_GETCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='GetCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.GetCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.GetCertificateRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.certificatemanager.v1.GetCertificateRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=486,
)


_LISTCERTIFICATESREQUEST = _descriptor.Descriptor(
  name='ListCertificatesRequest',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.view', index=3,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=676,
)


_LISTCERTIFICATESRESPONSE = _descriptor.Descriptor(
  name='ListCertificatesResponse',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesResponse.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=800,
)


_LISTVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListVersionsRequest',
  full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=923,
)


_LISTVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListVersionsResponse',
  full_name='yandex.cloud.certificatemanager.v1.ListVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='yandex.cloud.certificatemanager.v1.ListVersionsResponse.versions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.certificatemanager.v1.ListVersionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=1035,
)


_CREATECERTIFICATEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1488,
)

_CREATECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='CreateCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.certificate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\007<=32768', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.chain', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\t<=2097152', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.private_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\0101-524288', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECERTIFICATEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1488,
)


_CREATECERTIFICATEMETADATA = _descriptor.Descriptor(
  name='CreateCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.CreateCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1490,
  serialized_end=1541,
)


_UPDATECERTIFICATEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1488,
)

_UPDATECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='UpdateCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.certificate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\007<=32768', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.chain', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\t<=2097152', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.private_key', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\010<=524288', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECERTIFICATEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=2044,
)


_UPDATECERTIFICATEMETADATA = _descriptor.Descriptor(
  name='UpdateCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2097,
)


_DELETECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='DeleteCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2099,
  serialized_end=2163,
)


_DELETECERTIFICATEMETADATA = _descriptor.Descriptor(
  name='DeleteCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2165,
  serialized_end=2216,
)


_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1488,
)

_REQUESTNEWCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='RequestNewCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domains', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.domains', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='challenge_type', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.challenge_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2219,
  serialized_end=2666,
)


_REQUESTNEWCERTIFICATEMETADATA = _descriptor.Descriptor(
  name='RequestNewCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2668,
  serialized_end=2723,
)


_LISTCERTIFICATEOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListCertificateOperationsRequest',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2860,
)


_LISTCERTIFICATEOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListCertificateOperationsResponse',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2862,
  serialized_end=2977,
)

_GETCERTIFICATEREQUEST.fields_by_name['view'].enum_type = _CERTIFICATEVIEW
_LISTCERTIFICATESREQUEST.fields_by_name['view'].enum_type = _CERTIFICATEVIEW
_LISTCERTIFICATESRESPONSE.fields_by_name['certificates'].message_type = yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._CERTIFICATE
_LISTVERSIONSRESPONSE.fields_by_name['versions'].message_type = yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._VERSION
_CREATECERTIFICATEREQUEST_LABELSENTRY.containing_type = _CREATECERTIFICATEREQUEST
_CREATECERTIFICATEREQUEST.fields_by_name['labels'].message_type = _CREATECERTIFICATEREQUEST_LABELSENTRY
_UPDATECERTIFICATEREQUEST_LABELSENTRY.containing_type = _UPDATECERTIFICATEREQUEST
_UPDATECERTIFICATEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATECERTIFICATEREQUEST.fields_by_name['labels'].message_type = _UPDATECERTIFICATEREQUEST_LABELSENTRY
_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY.containing_type = _REQUESTNEWCERTIFICATEREQUEST
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels'].message_type = _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['challenge_type'].enum_type = yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._CHALLENGETYPE
_LISTCERTIFICATEOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetCertificateRequest'] = _GETCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['ListCertificatesRequest'] = _LISTCERTIFICATESREQUEST
DESCRIPTOR.message_types_by_name['ListCertificatesResponse'] = _LISTCERTIFICATESRESPONSE
DESCRIPTOR.message_types_by_name['ListVersionsRequest'] = _LISTVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListVersionsResponse'] = _LISTVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreateCertificateRequest'] = _CREATECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['CreateCertificateMetadata'] = _CREATECERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['UpdateCertificateRequest'] = _UPDATECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['UpdateCertificateMetadata'] = _UPDATECERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['DeleteCertificateRequest'] = _DELETECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['DeleteCertificateMetadata'] = _DELETECERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['RequestNewCertificateRequest'] = _REQUESTNEWCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['RequestNewCertificateMetadata'] = _REQUESTNEWCERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['ListCertificateOperationsRequest'] = _LISTCERTIFICATEOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListCertificateOperationsResponse'] = _LISTCERTIFICATEOPERATIONSRESPONSE
DESCRIPTOR.enum_types_by_name['CertificateView'] = _CERTIFICATEVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCertificateRequest = _reflection.GeneratedProtocolMessageType('GetCertificateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.GetCertificateRequest)
  })
_sym_db.RegisterMessage(GetCertificateRequest)

ListCertificatesRequest = _reflection.GeneratedProtocolMessageType('ListCertificatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATESREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificatesRequest)
  })
_sym_db.RegisterMessage(ListCertificatesRequest)

ListCertificatesResponse = _reflection.GeneratedProtocolMessageType('ListCertificatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATESRESPONSE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificatesResponse)
  })
_sym_db.RegisterMessage(ListCertificatesResponse)

ListVersionsRequest = _reflection.GeneratedProtocolMessageType('ListVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVERSIONSREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListVersionsRequest)
  })
_sym_db.RegisterMessage(ListVersionsRequest)

ListVersionsResponse = _reflection.GeneratedProtocolMessageType('ListVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVERSIONSRESPONSE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListVersionsResponse)
  })
_sym_db.RegisterMessage(ListVersionsResponse)

CreateCertificateRequest = _reflection.GeneratedProtocolMessageType('CreateCertificateRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECERTIFICATEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.CreateCertificateRequest)
  })
_sym_db.RegisterMessage(CreateCertificateRequest)
_sym_db.RegisterMessage(CreateCertificateRequest.LabelsEntry)

CreateCertificateMetadata = _reflection.GeneratedProtocolMessageType('CreateCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATECERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.CreateCertificateMetadata)
  })
_sym_db.RegisterMessage(CreateCertificateMetadata)

UpdateCertificateRequest = _reflection.GeneratedProtocolMessageType('UpdateCertificateRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECERTIFICATEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.UpdateCertificateRequest)
  })
_sym_db.RegisterMessage(UpdateCertificateRequest)
_sym_db.RegisterMessage(UpdateCertificateRequest.LabelsEntry)

UpdateCertificateMetadata = _reflection.GeneratedProtocolMessageType('UpdateCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.UpdateCertificateMetadata)
  })
_sym_db.RegisterMessage(UpdateCertificateMetadata)

DeleteCertificateRequest = _reflection.GeneratedProtocolMessageType('DeleteCertificateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.DeleteCertificateRequest)
  })
_sym_db.RegisterMessage(DeleteCertificateRequest)

DeleteCertificateMetadata = _reflection.GeneratedProtocolMessageType('DeleteCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.DeleteCertificateMetadata)
  })
_sym_db.RegisterMessage(DeleteCertificateMetadata)

RequestNewCertificateRequest = _reflection.GeneratedProtocolMessageType('RequestNewCertificateRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _REQUESTNEWCERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest)
  })
_sym_db.RegisterMessage(RequestNewCertificateRequest)
_sym_db.RegisterMessage(RequestNewCertificateRequest.LabelsEntry)

RequestNewCertificateMetadata = _reflection.GeneratedProtocolMessageType('RequestNewCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTNEWCERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.RequestNewCertificateMetadata)
  })
_sym_db.RegisterMessage(RequestNewCertificateMetadata)

ListCertificateOperationsRequest = _reflection.GeneratedProtocolMessageType('ListCertificateOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATEOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest)
  })
_sym_db.RegisterMessage(ListCertificateOperationsRequest)

ListCertificateOperationsResponse = _reflection.GeneratedProtocolMessageType('ListCertificateOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATEOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse)
  })
_sym_db.RegisterMessage(ListCertificateOperationsResponse)


DESCRIPTOR._options = None
_GETCERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
_LISTCERTIFICATESREQUEST.fields_by_name['folder_id']._options = None
_LISTCERTIFICATESREQUEST.fields_by_name['page_size']._options = None
_LISTCERTIFICATESREQUEST.fields_by_name['page_token']._options = None
_LISTVERSIONSREQUEST.fields_by_name['certificate_id']._options = None
_LISTVERSIONSREQUEST.fields_by_name['page_size']._options = None
_LISTVERSIONSREQUEST.fields_by_name['page_token']._options = None
_CREATECERTIFICATEREQUEST_LABELSENTRY._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['name']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['description']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
_UPDATECERTIFICATEREQUEST_LABELSENTRY._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['name']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['description']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
_DELETECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['name']._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['description']._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels']._options = None
_LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['certificate_id']._options = None
_LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_CERTIFICATESERVICE = _descriptor.ServiceDescriptor(
  name='CertificateService',
  full_name='yandex.cloud.certificatemanager.v1.CertificateService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3020,
  serialized_end=5398,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._CERTIFICATE,
    serialized_options=b'\202\323\344\223\0027\0225/certificate-manager/v1/certificates/{certificate_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.List',
    index=1,
    containing_service=None,
    input_type=_LISTCERTIFICATESREQUEST,
    output_type=_LISTCERTIFICATESRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/certificate-manager/v1/certificates',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListVersions',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.ListVersions',
    index=2,
    containing_service=None,
    input_type=_LISTVERSIONSREQUEST,
    output_type=_LISTVERSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002@\022>/certificate-manager/v1/certificates/{certificate_id}/versions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Create',
    index=3,
    containing_service=None,
    input_type=_CREATECERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002)\"$/certificate-manager/v1/certificates:\001*\262\322*(\n\031CreateCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Update',
    index=4,
    containing_service=None,
    input_type=_UPDATECERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002:25/certificate-manager/v1/certificates/{certificate_id}:\001*\262\322*(\n\031UpdateCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Delete',
    index=5,
    containing_service=None,
    input_type=_DELETECERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0027*5/certificate-manager/v1/certificates/{certificate_id}\262\322*(\n\031DeleteCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestNew',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.RequestNew',
    index=6,
    containing_service=None,
    input_type=_REQUESTNEWCERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0024\"//certificate-manager/v1/certificates/requestNew:\001*\262\322*,\n\035RequestNewCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTCERTIFICATEOPERATIONSREQUEST,
    output_type=_LISTCERTIFICATEOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002B\022@/certificate-manager/v1/certificates/{certificate_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.ListAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002G\022E/certificate-manager/v1/certificates/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.SetAccessBindings',
    index=9,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.UpdateAccessBindings',
    index=10,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CERTIFICATESERVICE)

DESCRIPTOR.services_by_name['CertificateService'] = _CERTIFICATESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/version.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/k8s/v1/version.proto',
  package='yandex.cloud.k8s.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!yandex/cloud/k8s/v1/version.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1dyandex/cloud/validation.proto\"\x80\x01\n\x0bVersionInfo\x12\x17\n\x0f\x63urrent_version\x18\x01 \x01(\t\x12\x1e\n\x16new_revision_available\x18\x02 \x01(\x08\x12\x1c\n\x14new_revision_summary\x18\x03 \x01(\t\x12\x1a\n\x12version_deprecated\x18\x04 \x01(\x08\"T\n\x11UpdateVersionSpec\x12\x11\n\x07version\x18\x01 \x01(\tH\x00\x12\x19\n\x0flatest_revision\x18\x02 \x01(\x08H\x00\x42\x11\n\tspecifier\x12\x04\xc0\xc1\x31\x01\x42V\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_VERSIONINFO = _descriptor.Descriptor(
  name='VersionInfo',
  full_name='yandex.cloud.k8s.v1.VersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_version', full_name='yandex.cloud.k8s.v1.VersionInfo.current_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_revision_available', full_name='yandex.cloud.k8s.v1.VersionInfo.new_revision_available', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_revision_summary', full_name='yandex.cloud.k8s.v1.VersionInfo.new_revision_summary', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_deprecated', full_name='yandex.cloud.k8s.v1.VersionInfo.version_deprecated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=218,
)


_UPDATEVERSIONSPEC = _descriptor.Descriptor(
  name='UpdateVersionSpec',
  full_name='yandex.cloud.k8s.v1.UpdateVersionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.k8s.v1.UpdateVersionSpec.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_revision', full_name='yandex.cloud.k8s.v1.UpdateVersionSpec.latest_revision', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='specifier', full_name='yandex.cloud.k8s.v1.UpdateVersionSpec.specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=220,
  serialized_end=304,
)

_UPDATEVERSIONSPEC.oneofs_by_name['specifier'].fields.append(
  _UPDATEVERSIONSPEC.fields_by_name['version'])
_UPDATEVERSIONSPEC.fields_by_name['version'].containing_oneof = _UPDATEVERSIONSPEC.oneofs_by_name['specifier']
_UPDATEVERSIONSPEC.oneofs_by_name['specifier'].fields.append(
  _UPDATEVERSIONSPEC.fields_by_name['latest_revision'])
_UPDATEVERSIONSPEC.fields_by_name['latest_revision'].containing_oneof = _UPDATEVERSIONSPEC.oneofs_by_name['specifier']
DESCRIPTOR.message_types_by_name['VersionInfo'] = _VERSIONINFO
DESCRIPTOR.message_types_by_name['UpdateVersionSpec'] = _UPDATEVERSIONSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'yandex.cloud.k8s.v1.version_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)

UpdateVersionSpec = _reflection.GeneratedProtocolMessageType('UpdateVersionSpec', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVERSIONSPEC,
  '__module__' : 'yandex.cloud.k8s.v1.version_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.UpdateVersionSpec)
  })
_sym_db.RegisterMessage(UpdateVersionSpec)


DESCRIPTOR._options = None
_UPDATEVERSIONSPEC.oneofs_by_name['specifier']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/mongo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/mongo.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/datatransfer/v1/endpoint/mongo.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\x84\x01\n\x0eOnPremiseMongo\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12@\n\x08tls_mode\x18\x06 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSMode\x12\x13\n\x0breplica_set\x18\x05 \x01(\t\"\xee\x01\n\x16MongoConnectionOptions\x12\x18\n\x0emdb_cluster_id\x18\x01 \x01(\tH\x00\x12K\n\non_premise\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongoH\x00\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x13\n\x0b\x61uth_source\x18\x05 \x01(\tB\t\n\x07\x61\x64\x64ress\"|\n\x0fMongoConnection\x12[\n\x12\x63onnection_options\x18\x03 \x01(\x0b\x32=.yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptionsH\x00\x42\x0c\n\nconnection\"A\n\x0fMongoCollection\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\"\xca\x02\n\x0bMongoSource\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoConnection\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x0b \x03(\t\x12K\n\x0b\x63ollections\x18\x06 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoCollection\x12T\n\x14\x65xcluded_collections\x18\x07 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoCollection\x12 \n\x18secondary_preferred_mode\x18\x08 \x01(\x08\"\xe5\x01\n\x0bMongoTarget\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoConnection\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x08 \x03(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12L\n\x0e\x63leanup_policy\x18\x06 \x01(\x0e\x32\x34.yandex.cloud.datatransfer.v1.endpoint.CleanupPolicyB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2.DESCRIPTOR,])




_ONPREMISEMONGO = _descriptor.Descriptor(
  name='OnPremiseMongo',
  full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.hosts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.port', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.tls_mode', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replica_set', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.replica_set', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=277,
)


_MONGOCONNECTIONOPTIONS = _descriptor.Descriptor(
  name='MongoConnectionOptions',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mdb_cluster_id', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.mdb_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_premise', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.on_premise', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.user', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.password', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_source', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.auth_source', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=280,
  serialized_end=518,
)


_MONGOCONNECTION = _descriptor.Descriptor(
  name='MongoConnection',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_options', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnection.connection_options', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnection.connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=520,
  serialized_end=644,
)


_MONGOCOLLECTION = _descriptor.Descriptor(
  name='MongoCollection',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoCollection.database_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoCollection.collection_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=711,
)


_MONGOSOURCE = _descriptor.Descriptor(
  name='MongoSource',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.security_groups', index=2,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collections', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.collections', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_collections', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.excluded_collections', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_preferred_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.secondary_preferred_mode', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=1044,
)


_MONGOTARGET = _descriptor.Descriptor(
  name='MongoTarget',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.subnet_id', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.security_groups', index=2,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.database', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.cleanup_policy', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1276,
)

_ONPREMISEMONGO.fields_by_name['tls_mode'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._TLSMODE
_MONGOCONNECTIONOPTIONS.fields_by_name['on_premise'].message_type = _ONPREMISEMONGO
_MONGOCONNECTIONOPTIONS.fields_by_name['password'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._SECRET
_MONGOCONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _MONGOCONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'])
_MONGOCONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'].containing_oneof = _MONGOCONNECTIONOPTIONS.oneofs_by_name['address']
_MONGOCONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _MONGOCONNECTIONOPTIONS.fields_by_name['on_premise'])
_MONGOCONNECTIONOPTIONS.fields_by_name['on_premise'].containing_oneof = _MONGOCONNECTIONOPTIONS.oneofs_by_name['address']
_MONGOCONNECTION.fields_by_name['connection_options'].message_type = _MONGOCONNECTIONOPTIONS
_MONGOCONNECTION.oneofs_by_name['connection'].fields.append(
  _MONGOCONNECTION.fields_by_name['connection_options'])
_MONGOCONNECTION.fields_by_name['connection_options'].containing_oneof = _MONGOCONNECTION.oneofs_by_name['connection']
_MONGOSOURCE.fields_by_name['connection'].message_type = _MONGOCONNECTION
_MONGOSOURCE.fields_by_name['collections'].message_type = _MONGOCOLLECTION
_MONGOSOURCE.fields_by_name['excluded_collections'].message_type = _MONGOCOLLECTION
_MONGOTARGET.fields_by_name['connection'].message_type = _MONGOCONNECTION
_MONGOTARGET.fields_by_name['cleanup_policy'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._CLEANUPPOLICY
DESCRIPTOR.message_types_by_name['OnPremiseMongo'] = _ONPREMISEMONGO
DESCRIPTOR.message_types_by_name['MongoConnectionOptions'] = _MONGOCONNECTIONOPTIONS
DESCRIPTOR.message_types_by_name['MongoConnection'] = _MONGOCONNECTION
DESCRIPTOR.message_types_by_name['MongoCollection'] = _MONGOCOLLECTION
DESCRIPTOR.message_types_by_name['MongoSource'] = _MONGOSOURCE
DESCRIPTOR.message_types_by_name['MongoTarget'] = _MONGOTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OnPremiseMongo = _reflection.GeneratedProtocolMessageType('OnPremiseMongo', (_message.Message,), {
  'DESCRIPTOR' : _ONPREMISEMONGO,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo)
  })
_sym_db.RegisterMessage(OnPremiseMongo)

MongoConnectionOptions = _reflection.GeneratedProtocolMessageType('MongoConnectionOptions', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCONNECTIONOPTIONS,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions)
  })
_sym_db.RegisterMessage(MongoConnectionOptions)

MongoConnection = _reflection.GeneratedProtocolMessageType('MongoConnection', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCONNECTION,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoConnection)
  })
_sym_db.RegisterMessage(MongoConnection)

MongoCollection = _reflection.GeneratedProtocolMessageType('MongoCollection', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCOLLECTION,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoCollection)
  })
_sym_db.RegisterMessage(MongoCollection)

MongoSource = _reflection.GeneratedProtocolMessageType('MongoSource', (_message.Message,), {
  'DESCRIPTOR' : _MONGOSOURCE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoSource)
  })
_sym_db.RegisterMessage(MongoSource)

MongoTarget = _reflection.GeneratedProtocolMessageType('MongoTarget', (_message.Message,), {
  'DESCRIPTOR' : _MONGOTARGET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoTarget)
  })
_sym_db.RegisterMessage(MongoTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/target_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/target_group.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/apploadbalancer/v1/target_group.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb2\x02\n\x0bTargetGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12H\n\x06labels\x18\x05 \x03(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.TargetGroup.LabelsEntry\x12\x38\n\x07targets\x18\x06 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x06Target\x12\x14\n\nip_address\x18\x01 \x01(\tH\x00\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\x12\x1c\n\x14private_ipv4_address\x18\x04 \x01(\x08\x42\x14\n\x0c\x61\x64\x64ress_type\x12\x04\xc0\xc1\x31\x01\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_TARGETGROUP_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=458,
)

_TARGETGROUP = _descriptor.Descriptor(
  name='TargetGroup',
  full_name='yandex.cloud.apploadbalancer.v1.TargetGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.folder_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targets', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.targets', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.apploadbalancer.v1.TargetGroup.created_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TARGETGROUP_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=458,
)


_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='yandex.cloud.apploadbalancer.v1.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='yandex.cloud.apploadbalancer.v1.Target.ip_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.apploadbalancer.v1.Target.subnet_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_ipv4_address', full_name='yandex.cloud.apploadbalancer.v1.Target.private_ipv4_address', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address_type', full_name='yandex.cloud.apploadbalancer.v1.Target.address_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=460,
  serialized_end=561,
)

_TARGETGROUP_LABELSENTRY.containing_type = _TARGETGROUP
_TARGETGROUP.fields_by_name['labels'].message_type = _TARGETGROUP_LABELSENTRY
_TARGETGROUP.fields_by_name['targets'].message_type = _TARGET
_TARGETGROUP.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TARGET.oneofs_by_name['address_type'].fields.append(
  _TARGET.fields_by_name['ip_address'])
_TARGET.fields_by_name['ip_address'].containing_oneof = _TARGET.oneofs_by_name['address_type']
DESCRIPTOR.message_types_by_name['TargetGroup'] = _TARGETGROUP
DESCRIPTOR.message_types_by_name['Target'] = _TARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TargetGroup = _reflection.GeneratedProtocolMessageType('TargetGroup', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TARGETGROUP_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TargetGroup.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _TARGETGROUP,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TargetGroup)
  })
_sym_db.RegisterMessage(TargetGroup)
_sym_db.RegisterMessage(TargetGroup.LabelsEntry)

Target = _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {
  'DESCRIPTOR' : _TARGET,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.Target)
  })
_sym_db.RegisterMessage(Target)


DESCRIPTOR._options = None
_TARGETGROUP_LABELSENTRY._options = None
_TARGET.oneofs_by_name['address_type']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/certificatemanager/v1/certificate_content_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/certificatemanager/v1/certificate_content_service.proto',
  package='yandex.cloud.certificatemanager.v1',
  syntax='proto3',
  serialized_options=b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDyandex/cloud/certificatemanager/v1/certificate_content_service.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1cgoogle/api/annotations.proto\"g\n\x1dGetCertificateContentResponse\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x03 \x03(\t\x12\x13\n\x0bprivate_key\x18\x04 \x01(\t\"J\n\x1cGetCertificateContentRequest\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t2\xf2\x01\n\x19\x43\x65rtificateContentService\x12\xd4\x01\n\x03Get\x12@.yandex.cloud.certificatemanager.v1.GetCertificateContentRequest\x1a\x41.yandex.cloud.certificatemanager.v1.GetCertificateContentResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/certificate-manager/v1/certificates/{certificate_id}:getContentB\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETCERTIFICATECONTENTRESPONSE = _descriptor.Descriptor(
  name='GetCertificateContentResponse',
  full_name='yandex.cloud.certificatemanager.v1.GetCertificateContentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.GetCertificateContentResponse.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_chain', full_name='yandex.cloud.certificatemanager.v1.GetCertificateContentResponse.certificate_chain', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='yandex.cloud.certificatemanager.v1.GetCertificateContentResponse.private_key', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=241,
)


_GETCERTIFICATECONTENTREQUEST = _descriptor.Descriptor(
  name='GetCertificateContentRequest',
  full_name='yandex.cloud.certificatemanager.v1.GetCertificateContentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.GetCertificateContentRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='yandex.cloud.certificatemanager.v1.GetCertificateContentRequest.version_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=317,
)

DESCRIPTOR.message_types_by_name['GetCertificateContentResponse'] = _GETCERTIFICATECONTENTRESPONSE
DESCRIPTOR.message_types_by_name['GetCertificateContentRequest'] = _GETCERTIFICATECONTENTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCertificateContentResponse = _reflection.GeneratedProtocolMessageType('GetCertificateContentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCERTIFICATECONTENTRESPONSE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_content_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.GetCertificateContentResponse)
  })
_sym_db.RegisterMessage(GetCertificateContentResponse)

GetCertificateContentRequest = _reflection.GeneratedProtocolMessageType('GetCertificateContentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCERTIFICATECONTENTREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_content_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.GetCertificateContentRequest)
  })
_sym_db.RegisterMessage(GetCertificateContentRequest)


DESCRIPTOR._options = None

_CERTIFICATECONTENTSERVICE = _descriptor.ServiceDescriptor(
  name='CertificateContentService',
  full_name='yandex.cloud.certificatemanager.v1.CertificateContentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=320,
  serialized_end=562,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.certificatemanager.v1.CertificateContentService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCERTIFICATECONTENTREQUEST,
    output_type=_GETCERTIFICATECONTENTRESPONSE,
    serialized_options=b'\202\323\344\223\002B\022@/certificate-manager/v1/certificates/{certificate_id}:getContent',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CERTIFICATECONTENTSERVICE)

DESCRIPTOR.services_by_name['CertificateContentService'] = _CERTIFICATECONTENTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadbalancer/v1/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadbalancer/v1/health_check.proto',
  package='yandex.cloud.loadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/loadbalancer/v1/health_check.proto\x12\x1cyandex.cloud.loadbalancer.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dyandex/cloud/validation.proto\"\xf5\x03\n\x0bHealthCheck\x12\x33\n\x04name\x18\x01 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x13unhealthy_threshold\x18\x04 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x32-10\x12#\n\x11healthy_threshold\x18\x05 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x32-10\x12K\n\x0btcp_options\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.loadbalancer.v1.HealthCheck.TcpOptionsH\x00\x12M\n\x0chttp_options\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.loadbalancer.v1.HealthCheck.HttpOptionsH\x00\x1a\'\n\nTcpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x1a\x36\n\x0bHttpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x12\x0c\n\x04path\x18\x02 \x01(\tB\x0f\n\x07options\x12\x04\xc0\xc1\x31\x01\x42q\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_HEALTHCHECK_TCPOPTIONS = _descriptor.Descriptor(
  name='TcpOptions',
  full_name='yandex.cloud.loadbalancer.v1.HealthCheck.TcpOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.TcpOptions.port', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=573,
)

_HEALTHCHECK_HTTPOPTIONS = _descriptor.Descriptor(
  name='HttpOptions',
  full_name='yandex.cloud.loadbalancer.v1.HealthCheck.HttpOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.HttpOptions.port', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.HttpOptions.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=629,
)

_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='yandex.cloud.loadbalancer.v1.HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_threshold', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.unhealthy_threshold', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0042-10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthy_threshold', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.healthy_threshold', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0042-10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_options', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.tcp_options', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_options', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.http_options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECK_TCPOPTIONS, _HEALTHCHECK_HTTPOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='options', full_name='yandex.cloud.loadbalancer.v1.HealthCheck.options',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=145,
  serialized_end=646,
)

_HEALTHCHECK_TCPOPTIONS.containing_type = _HEALTHCHECK
_HEALTHCHECK_HTTPOPTIONS.containing_type = _HEALTHCHECK
_HEALTHCHECK.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['tcp_options'].message_type = _HEALTHCHECK_TCPOPTIONS
_HEALTHCHECK.fields_by_name['http_options'].message_type = _HEALTHCHECK_HTTPOPTIONS
_HEALTHCHECK.oneofs_by_name['options'].fields.append(
  _HEALTHCHECK.fields_by_name['tcp_options'])
_HEALTHCHECK.fields_by_name['tcp_options'].containing_oneof = _HEALTHCHECK.oneofs_by_name['options']
_HEALTHCHECK.oneofs_by_name['options'].fields.append(
  _HEALTHCHECK.fields_by_name['http_options'])
_HEALTHCHECK.fields_by_name['http_options'].containing_oneof = _HEALTHCHECK.oneofs_by_name['options']
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {

  'TcpOptions' : _reflection.GeneratedProtocolMessageType('TcpOptions', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_TCPOPTIONS,
    '__module__' : 'yandex.cloud.loadbalancer.v1.health_check_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadbalancer.v1.HealthCheck.TcpOptions)
    })
  ,

  'HttpOptions' : _reflection.GeneratedProtocolMessageType('HttpOptions', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_HTTPOPTIONS,
    '__module__' : 'yandex.cloud.loadbalancer.v1.health_check_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadbalancer.v1.HealthCheck.HttpOptions)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'yandex.cloud.loadbalancer.v1.health_check_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadbalancer.v1.HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)
_sym_db.RegisterMessage(HealthCheck.TcpOptions)
_sym_db.RegisterMessage(HealthCheck.HttpOptions)


DESCRIPTOR._options = None
_HEALTHCHECK_TCPOPTIONS.fields_by_name['port']._options = None
_HEALTHCHECK_HTTPOPTIONS.fields_by_name['port']._options = None
_HEALTHCHECK.oneofs_by_name['options']._options = None
_HEALTHCHECK.fields_by_name['name']._options = None
_HEALTHCHECK.fields_by_name['unhealthy_threshold']._options = None
_HEALTHCHECK.fields_by_name['healthy_threshold']._options = None
# @@protoc_insertion_point(module_scope)
